
|version-badge| |license-badge| |pypi-downloads-badge| |pypi-version-badge| 

==============================================================
docit Documentation
==============================================================

**docit** is a python package.

Documentation Contents:
------------------------------

.. toctree::
   :maxdepth: 2

   README

   __package__
   ext
   version

   LICENSE


Indices and tables
--------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Version
-------------------

|version-badge|

This documentation is for docit |release|.


Project Resources
------------------------
* `docit project homepage (bitbucket) <https://bitbucket.org/bmearns/docit>`_
* `docit on pypi <https://pypi.python.org/pypi/docit>`_
* Online documentation:
    * `Read The Docs (.org) <http://docit.readthedocs.org/>`_
    * `Python Hosted (.org) <http://pythonhosted.org/docit/>`_
